@@ -1,4 +1,5 @@
-from beanie import Document, PydanticObjectId
+from beanie import Document
+from bson.objectid import ObjectId
 from pydantic import Field
 from uuid import uuid4
 from datetime import datetime,UTC
@@ -6,7 +7,7 @@ class BaseDocument(Document):
     """
     Base document class for all documents of NoSQL database
     """
-    id: PydanticObjectId = Field(default_factory=PydanticObjectId, unique=True, index=True,nullable=False)
+    id: ObjectId = Field(default_factory=ObjectId, alias="_id")
     uuid: str = Field(default_factory=lambda: str(uuid4()), unique=True, index=True,nullable=False)
     created_at: datetime = Field(default_factory=lambda: datetime.now(UTC))
     updated_at: datetime = Field(default_factory=lambda: datetime.now(UTC))
