@@ -21,7 +21,7 @@ class BaseCollectionService:
         return await self.repository.add_field(collection_name, field)
     
     async def delete_field(self, collection_name: str, field: str):
-        return await self.repository.delete_field(collection_name, field)
+        return await self.repository.delete_field(field,collection_name)
     
     async def get_collection_names(self):
         return await self.repository.get_collection_names()
